<?php
/**
 * A filter for updating the user account like last activity, last action
 * performed and so on.
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2011 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class UserUpdateFilter extends BaseFilter implements Filterable {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Creates an instance of this filter class
	 *
	 * @return	$filterInstance			An instance of this filter class
	 */
	public static final function createUserUpdateFilter () {
		// Get a new instance
		$filterInstance = new UserUpdateFilter();

		// Return the instance
		return $filterInstance;
	}

	/**
	 * Executes the filter with given request and response objects
	 *
	 * @param	$requestInstance	An instance of a class with an Requestable interface
	 * @param	$responseInstance	An instance of a class with an Responseable interface
	 * @return	void
	 * @todo	Add more user updates here
	 */
	public function execute (Requestable $requestInstance, Responseable $responseInstance) {
		// Get user instance from registry
		$userInstance = Registry::getRegistry()->getInstance('user');

		// Now update last activity
		$userInstance->updateLastActivity($requestInstance);

		// Update auth data as well
		$authInstance = Registry::getRegistry()->getInstance('auth');
		$authInstance->updateAuthData();

		// Write all updates to the database
		$userInstance->flushPendingUpdates();
	}
}

// [EOF]
?>
